==> myoss-starter-cache-2.0.1.RELEASE.jar: README.md <==
# myoss-starter-projects

[![Maven Central](https://img.shields.io/maven-central/v/app.myoss.cloud.boot/myoss-starter-projects.svg)](https://maven-badges.herokuapp.com/maven-central/app.myoss.cloud.boot/myoss-starter-projects/)
[![GitHub release](https://img.shields.io/github/release/myoss-cloud/myoss-starter-projects.svg)](https://github.com/myoss-cloud/myoss-starter-projects/releases)
[![License](https://img.shields.io/badge/license-Apache%202-4EB1BA.svg)](https://www.apache.org/licenses/LICENSE-2.0.html)

## Documentation

- [Documentation Home](https://github.com/myoss-cloud/myoss-starter-projects/wiki)

## Download

- [maven][1]
- [the latest JAR][2]  

[1]: http://repo1.maven.org/maven2/app.myoss.cloud.boot/boot/myoss-starter-projects/  
[2]: https://search.maven.org/remote_content?g=app.myoss.cloud.boot&a=myoss-starter-projects&v=LATEST

## Maven

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-projects</artifactId>
    <version>2.0.1.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-core</artifactId>
    <version>2.0.1.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-apm</artifactId>
    <version>2.0.1.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-web</artifactId>
    <version>2.0.1.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-cache</artifactId>
    <version>2.0.1.RELEASE</version>
</dependency>
```

==> myoss-starter-cache-2.0.2.RELEASE.jar: README.md <==
# myoss-starter-projects

[![Maven Central](https://img.shields.io/maven-central/v/app.myoss.cloud.boot/myoss-starter-projects.svg)](https://maven-badges.herokuapp.com/maven-central/app.myoss.cloud.boot/myoss-starter-projects/)
[![GitHub release](https://img.shields.io/github/release/myoss-cloud/myoss-starter-projects.svg)](https://github.com/myoss-cloud/myoss-starter-projects/releases)
[![License](https://img.shields.io/badge/license-Apache%202-4EB1BA.svg)](https://www.apache.org/licenses/LICENSE-2.0.html)

## Documentation

- [Documentation Home](https://github.com/myoss-cloud/myoss-starter-projects/wiki)

## Download

- [maven][1]
- [the latest JAR][2]  

[1]: http://repo1.maven.org/maven2/app/myoss/cloud/boot/myoss-starter-projects/  
[2]: https://search.maven.org/remote_content?g=app.myoss.cloud.boot&a=myoss-starter-projects&v=LATEST

## Maven

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-projects</artifactId>
    <version>2.0.2.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-core</artifactId>
    <version>2.0.2.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-apm</artifactId>
    <version>2.0.2.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-web</artifactId>
    <version>2.0.2.RELEASE</version>
</dependency>
```

```xml
<dependency>
    <groupId>app.myoss.cloud.boot</groupId>
    <artifactId>myoss-starter-cache</artifactId>
    <version>2.0.2.RELEASE</version>
</dependency>
```
